"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.STSHelper = void 0;
const STS = require("@aws-sdk/client-sts");
const uuid_1 = require("uuid");
const typescript_helper_functions_1 = require("typescript-helper-functions");
class STSHelper extends typescript_helper_functions_1.BaseClass {
    constructor(logger, repository, options) {
        super(logger);
        options = this.ObjectOperations.IsNullOrEmpty(options)
            ? { region: 'us-east-1' }
            : options;
        this.Repository = repository || new STS.STS(options);
    }
    async AssumeRoleAsync(roleArn) {
        const action = `${STSHelper.name}.${this.AssumeRoleAsync.name}`;
        this.LogHelper.LogInputs(action, { roleArn });
        if (this.ObjectOperations.IsNullOrWhitespace(roleArn)) {
            throw new Error(`[${action}]-Must supply roleArn`);
        }
        const params = {
            RoleArn: roleArn,
            RoleSessionName: uuid_1.v4(),
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.assumeRole(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
}
exports.STSHelper = STSHelper;
//# sourceMappingURL=helper.js.map